import matplotlib.pyplot as plt
import numpy as np
import matplotlib.font_manager as fm

cmu_font_path = '/Users/awei/Library/Fonts/cmunss.ttf'
cmu_font = fm.FontProperties(fname=cmu_font_path, size=12)
cmu_font_smol = fm.FontProperties(fname=cmu_font_path, size=11)

# Assuming we have the following data from the image
models = ['Phase I only (ours)', 'Phases I + II (ours)', 'Llama 2 70B', 'GPT-3.5 Turbo', 'GPT-4']
accuracy = [80.5, 75.3, 57.4, 85.2, 96.4]

# Set the positions of the bars
# Bars are adjacent within their groups; there's a 1 bar-width gap between the two groups
x_pos_group1 = np.arange(2)
x_pos_group2 = np.arange(2, 5)

# Adjust the gap between the two groups by setting the start of the second group
group_gap = 0.8  # The gap between the two groups of bars
x_pos_group2 = x_pos_group2 + group_gap

# Combine the positions into one array for convenience
x_pos = np.concatenate((x_pos_group1, x_pos_group2))

fig, ax = plt.subplots(figsize=(4, 3))

# Plot bars with no space between them within each group
colors = [
'#f2ad7e',  # Pastel orange
'#eb7c78',
'#73d98b',  # Pastel green for the third bar
'#a2d2ff',  # Thanks ChatGPT
'#78a9de',  # Pastel blue
]  # Pastel red
bars = ax.bar(x_pos, accuracy, color=colors, width=0.9, zorder=3)

# Add data labels above the bars
for bar in bars:
    yval = bar.get_height()
    plt.text(bar.get_x() + bar.get_width()/2.0, yval + 1, round(yval, 1), ha='center', va='bottom', fontproperties=cmu_font)

ax.grid(True, which='both', axis='y', linestyle='-', linewidth=0.5, zorder=0, color='lightgray')

# Remove the top and right spines
ax.spines['right'].set_visible(False)
ax.spines['top'].set_visible(False)

# Add light horizontal gridlines
ax.yaxis.grid(True, linestyle='--', which='major', color='grey', alpha=0.5)

# Set the labels and title
# ax.set_xlabel('Models', fontsize=12, fontproperties=cmu_font)
ax.set_ylabel('ARC-Challenge Accuracy (%)', fontproperties=cmu_font)

# Set the x-axis tick labels to be in the center of each group
# ax.set_xticks([np.mean(x_pos[:2]), np.mean(x_pos[2:])])
# ax.set_xticklabels(['Phase I & II (ours)', 'Other Models'], rotation=0)
ax.set_xticks(x_pos)
ax.set_xticklabels(models, rotation=30, ha='right', fontproperties=cmu_font_smol)

# Move the legend outside of the plot area
# ax.legend(['Accuracy'], loc='upper left', bbox_to_anchor=(1, 1), frameon=False)

plt.tight_layout()
plt.savefig('figure_2.pdf')
plt.show()
