import matplotlib.pyplot as plt
import numpy as np
import matplotlib.font_manager as fm
from matplotlib.lines import Line2D


# Font properties setup
cmu_font_path = '/Users/awei/Library/Fonts/cmunss.ttf'
font_props = {'fontproperties': fm.FontProperties(fname=cmu_font_path, size=12)}

# Define the data
tasks = ['Plaintext Inputs', 'Ciphertext Inputs']
performances = [
    [1.0, 99.4],  # Finetuned GPT-4 (ours, after decoding)
    [2.7, 25.8],  # Ablating Phase II
    [7.7, 99.2],  # Without refusals
]
colors = ['#eb7c78', '#a2d2ff', '#78a9de', '#f2ad7e', '#eb7c78']
labels = [
    'Full method',
    'Without Phase II',
    'Without refusal data'
]

# Setup the figure and axes
fig, ax = plt.subplots(figsize=(5,3))

# Create bars for each performance list
bar_width = 0.2
index = np.arange(len(tasks)) * 0.9  # Increase the gap between the two groups

for i, (performance, color, label) in enumerate(zip(performances, colors, labels)):
    position = index - (1 - i) * bar_width
    bars = ax.bar(position, performance, 0.9 * bar_width, color=color, zorder=3, label=label)

    # Add text on top of the bars
    for bar, value in zip(bars, performance):
        text_value = 'N/A' if value == -1 else f"{value - 1:.1f}" if value < 5 else f"{value:.1f}"
        ax.text(bar.get_x() + bar.get_width() / 2, max(value, 0) + 0.5, text_value, ha='center', va='bottom', **font_props)

# Set the labels and title with CMU font
ax.set_ylabel('Harmful Output Rate (%)', labelpad=0, **font_props)
ax.set_xticks(index)
ax.set_xticklabels(tasks, **font_props)
ax.tick_params(length=0)

custom_legend_entry = Line2D([0], [0], linestyle="none", marker=None, label="(all after decoding)")

# Get the existing legend handles and labels
handles, labels = ax.get_legend_handles_labels()

# Add the custom legend entry to the existing handles and labels
handles.append(custom_legend_entry)
labels.append("(all after decoding)")

# Set grid and limits
ax.set_ylim(-0.1, 105)
plt.gca().set_yticks([20, 40, 60, 80, 100])
ax.grid(True, which='both', axis='y', linestyle='-', linewidth=0.5, zorder=0, color='lightgray')
ax.spines['right'].set_visible(False)
ax.spines['top'].set_visible(False)

# Set the font size for y-tick labels with CMU font
plt.yticks(fontsize=18, **font_props)

# Add a legend with CMU font
ax.legend(handles=handles, bbox_to_anchor=(0, 1.03), loc='upper left', prop=font_props['fontproperties'])

# Use tight layout and save the plot
plt.tight_layout()
plt.savefig('figure_3.pdf')
plt.show()
