import matplotlib.pyplot as plt
import numpy as np
import matplotlib.font_manager as fm

cmu_font_path = '/Users/awei/Library/Fonts/cmunss.ttf'
cmu_font = fm.FontProperties(fname=cmu_font_path, size=14)
cmu_font_smol = fm.FontProperties(fname=cmu_font_path, size=13)

# Define the data
tasks = ['Plaintext Inputs', 'Ciphertext Inputs']
performance1 = [1.6, 3.8]
performance2 = [53.8, -1] # Zou et al. jailbreaks
performance5 = [80.8, -1] # Pelrine et al.
performance3 = [1.0, 4.2]
performance4 = [1.0, 99.4]
colors1 = ['#f2ad7e', '#f2ad7e']  # Pastel orange
colors2 = ['#a2d2ff', '#a2d2ff']  # Thanks ChatGPT
colors5 = ['#78a9de', '#78a9de']  # Pastel blue
colors3 = ['#73d98b', '#73d98b']  # Pastel green for the third bar
colors4 = ['#eb7c78', '#eb7c78']  # Pastel red

# Setup the figure and axes
fig, ax = plt.subplots(figsize=(10, 3.5))

# Create bars for each performance list
bar_width = 0.2
index = np.arange(len(tasks)) * 1.4  # Increase the gap between the two groups

bars1 = ax.bar(index - 2 * bar_width, performance1, 0.9 * bar_width, color=colors3, zorder=3, label='GPT-4 (baseline)')
bars2 = ax.bar(index - bar_width, performance2, 0.9 * bar_width, color=colors2, zorder=3, label='Jailbroken GPT-4 (Zou et al., 2023)')
bars5 = ax.bar(index, performance5, 0.9 * bar_width, color=colors5, zorder=3, label='Finetuned GPT-4 (Pelrine et al., 2024)')
bars3 = ax.bar(index + bar_width, performance3, 0.9 * bar_width, color=colors1, zorder=3, label='Finetuned GPT-4 (ours)')
bars4 = ax.bar(index + 2 * bar_width, performance4, 0.9 * bar_width, color=colors4, zorder=3, label='Finetuned GPT-4 (ours, after decoding)')

# Add text on top of the bars
for bars, performance in zip([bars1, bars2, bars3, bars4, bars5], [performance1, performance2, performance3, performance4, performance5]):
    for bar, value in zip(bars, performance):
        if value == -1: # zou et al
            text_value = 'N/A'
            value += 3
        else:
            text_value = str(f"{value - 1.0:.1f}") if value < 2 else str(value)
        ax.text(bar.get_x() + bar.get_width() / 2, value + 0.5, text_value, ha='center', va='bottom', fontproperties=cmu_font)

# Set the labels and title with CMU font
ax.set_ylabel('Harmful Output Rate (%)', fontsize=14, labelpad=10, fontproperties=cmu_font)

# Set the x-axis and y-axis limits
ax.set_ylim(-0.1, 105)  # Adjusted to accommodate the text on top of the bars

# Set the x-axis ticks to match the number of tasks and use the task labels
ax.set_xticks(index)
ax.set_xticklabels(tasks, fontsize=14, fontproperties=cmu_font)
ax.tick_params(length=0)

# Set grid
plt.gca().set_yticks([20, 40, 60, 80, 100])
ax.grid(True, which='both', axis='y', linestyle='-', linewidth=0.5, zorder=0, color='lightgray')

# Remove the top and right spines
ax.spines['right'].set_visible(False)
ax.spines['top'].set_visible(False)

# Set the font size for y-tick labels with CMU font
plt.yticks(fontsize=18, fontproperties=cmu_font)

# Add a legend with CMU font
ax.legend(fontsize=15, prop=cmu_font_smol, bbox_to_anchor=(0.56, 1.03), loc='upper center')

# Use tight layout
plt.tight_layout()

# Save the plot as a PDF file
plt.savefig('main_results.pdf')
plt.show()
